==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/Fsc.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fsc:
	"""Fsc commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fsc", core, parent)

	def set(self, fsc: enums.NfcFsc, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:FSC \n
		Selects the maximum frame size in bytes. \n
			:param fsc: F16| F24| F32| F40| F48| F64| F96| F128| F256
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(fsc, enums.NfcFsc)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:FSC {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcFsc:
		"""[SOURce<HW>]:BB:NFC:CBLock<CH>:FSC \n
		Selects the maximum frame size in bytes. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: fsc: F16| F24| F32| F40| F48| F64| F96| F128| F256"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:FSC?')
		return Conversions.str_to_scalar_enum(response, enums.NfcFsc)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Nfc_/Cblock_/Fsc.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fsc:
	"""Fsc commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fsc", core, parent)

	def set(self, fsc: enums.NfcFsc, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:FSC \n
		Snippet: driver.source.bb.nfc.cblock.fsc.set(fsc = enums.NfcFsc.F128, channel = repcap.Channel.Default) \n
		Selects the maximum frame size in bytes. \n
			:param fsc: F16| F24| F32| F40| F48| F64| F96| F128| F256
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')"""
		param = Conversions.enum_scalar_to_str(fsc, enums.NfcFsc)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:FSC {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.NfcFsc:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:FSC \n
		Snippet: value: enums.NfcFsc = driver.source.bb.nfc.cblock.fsc.get(channel = repcap.Channel.Default) \n
		Selects the maximum frame size in bytes. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: fsc: F16| F24| F32| F40| F48| F64| F96| F128| F256"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{channel_cmd_val}:FSC?')
		return Conversions.str_to_scalar_enum(response, enums.NfcFsc)
